@@ -37,8 +37,8 @@ void bpc_attribCache_init(bpc_attribCache_info *ac, char *hostName, int backupNu
     ac->shareNameUM[BPC_MAXPATHLEN - 1] = '\0';
     bpc_fileNameEltMangle(ac->shareName, BPC_MAXPATHLEN, ac->shareNameUM);
     ac->shareNameLen = strlen(ac->shareName);
-    snprintf(ac->hostDir, BPC_MAXPATHLEN, "%s/pc/%s", BPC_TopDir, ac->hostName);
-    snprintf(ac->backupTopDir, BPC_MAXPATHLEN, "%s/pc/%s/%d", BPC_TopDir, ac->hostName, ac->backupNum);
+    snprintf(ac->hostDir, BPC_MAXPATHLEN, "%s/pc/%s", BPC_TopDir, hostName);
+    snprintf(ac->backupTopDir, BPC_MAXPATHLEN, "%s/pc/%s/%d", BPC_TopDir, hostName, ac->backupNum);
     bpc_path_create(ac->backupTopDir);
 
     bpc_hashtable_create(&ac->attrHT,  BPC_ATTRIBCACHE_DIR_HT_SIZE, sizeof(bpc_attribCache_dir));
@@ -99,7 +99,7 @@ void bpc_attribCache_setCurrentDirectory(bpc_attribCache_info *ac, char *dir)
 static void splitPath(bpc_attribCache_info *ac, char *dir, char *fileName, char *attribPath, char *path)
 {
     char *dirOrig = dir;
-    char fullPath[BPC_MAXPATHLEN];
+    char fullPath[2*BPC_MAXPATHLEN];
     size_t pathLen;
 
     /*
@@ -114,7 +114,7 @@ static void splitPath(bpc_attribCache_info *ac, char *dir, char *fileName, char
      * if this is a relative path, prepend ac->currentDir (provided ac->currentDir is set)
      */
     if ( path[0] != '/' && ac->currentDir[0] ) {
-        snprintf(fullPath, BPC_MAXPATHLEN, "%s/%s", ac->currentDir, path);
+        snprintf(fullPath, sizeof(fullPath), "%s/%s", ac->currentDir, path);
         path = fullPath;
     }
 
@@ -176,6 +176,15 @@ static void inodePath(UNUSED(bpc_attribCache_info *ac), char *indexStr, char *at
     *indexStr = '\0';
 }
 
+static void bpc_attribCache_removeDeletedEntries(bpc_attrib_file *file, void *arg)
+{
+    bpc_attribCache_dir *attr = (bpc_attribCache_dir*)arg;
+    if ( file->type != BPC_FTYPE_DELETED ) return;
+    attr->dirty = 1;
+    bpc_attrib_fileDestroy(file);
+    bpc_hashtable_nodeDelete(&attr->dir.filesHT, file);
+}
+
 static bpc_attribCache_dir *bpc_attribCache_loadPath(bpc_attribCache_info *ac, char *fileName, char *path)
 {
     char dir[BPC_MAXPATHLEN], attribPath[BPC_MAXPATHLEN];
@@ -209,7 +218,7 @@ static bpc_attribCache_dir *bpc_attribCache_loadPath(bpc_attribCache_info *ac, c
 
     if ( ac->bkupMergeCnt > 0 ) {
         int i;
-        char topDir[BPC_MAXPATHLEN], fullAttribPath[BPC_MAXPATHLEN];
+        char topDir[2*BPC_MAXPATHLEN], fullAttribPath[2*BPC_MAXPATHLEN];
 
         /*
          * Merge multiple attrib files to create the "view" for this backup.
@@ -293,6 +302,10 @@ static bpc_attribCache_dir *bpc_attribCache_loadPath(bpc_attribCache_info *ac, c
         if ( (status = bpc_attrib_dirRead(&attr->dir, ac->backupTopDir, attribPath, ac->backupNum)) ) {
             bpc_logErrf("bpc_attribCache_loadPath: bpc_attrib_dirRead(%s, %s) returned %d\n", ac->backupTopDir, attribPath, status);
         }
+        /*
+         * remove any extraneous BPC_FTYPE_DELETED file types
+         */
+	bpc_hashtable_iterate(&attr->dir.filesHT, (void*)bpc_attribCache_removeDeletedEntries, attr);
     }
     if ( bpc_hashtable_entryCount(&ac->attrHT) > BPC_ATTRIBCACHE_DIR_COUNT_MAX ) {
         bpc_attribCache_flush(ac, 0, NULL);
@@ -330,7 +343,7 @@ static bpc_attribCache_dir *bpc_attribCache_loadInode(bpc_attribCache_info *ac,
     attr->lruCnt = ac->cacheLruCnt++;
     if ( ac->bkupMergeCnt > 0 ) {
         int i;
-        char inodeDir[BPC_MAXPATHLEN], fullAttribPath[BPC_MAXPATHLEN];
+        char inodeDir[2*BPC_MAXPATHLEN], fullAttribPath[2*BPC_MAXPATHLEN];
 
         /*
          * Merge multiple attrib files to create the "view" for this backup.
@@ -396,7 +409,7 @@ static bpc_attribCache_dir *bpc_attribCache_loadInode(bpc_attribCache_info *ac,
         /*
          * non-merge case - read the single attrib file
          */
-        char inodeDir[BPC_MAXPATHLEN];
+        char inodeDir[2*BPC_MAXPATHLEN];
         snprintf(inodeDir, sizeof(inodeDir), "%s/%s", ac->backupTopDir, attribDir);
 
         if ( (status = bpc_attrib_dirRead(&attr->dir, inodeDir, attribFile, ac->backupNum)) ) {
@@ -588,7 +601,7 @@ static void bpc_attribCache_getDirEntry(bpc_attrib_file *file, dirEntry_info *in
 ssize_t bpc_attribCache_getDirEntries(bpc_attribCache_info *ac, char *path, char *entries, ssize_t entrySize)
 {
     bpc_attribCache_dir *attr;
-    char fileName[BPC_MAXPATHLEN], fullPath[BPC_MAXPATHLEN];
+    char fileName[BPC_MAXPATHLEN], fullPath[2*BPC_MAXPATHLEN];
     dirEntry_info info;
     size_t pathLen = strlen(path);
     ino_t inode = 0;
@@ -599,7 +612,7 @@ ssize_t bpc_attribCache_getDirEntries(bpc_attribCache_info *ac, char *path, char
     if ( pathLen >= BPC_MAXPATHLEN - 3 ) return -1;
     if ( pathLen == 1 && path[0] == '.' ) {
         if ( ac->currentDir[0] ) {
-            snprintf(fullPath, BPC_MAXPATHLEN, "%s/x", ac->currentDir);
+            snprintf(fullPath, sizeof(fullPath), "%s/x", ac->currentDir);
         } else {
             strcpy(fullPath, "/x");
         }
